PCB Environment: AStarCosts Struct Reference

PCB Environment 2

Loading...
Searching...
No Matches
Public Member Functions | Data Fields
AStarCosts Struct Reference

## Public Member Functions
void | reset ()
void | setViolationCostInf ()
void | setXYBiasNone ()
bool | valid () const
void | setPy (PyObject *)

## Data Fields
float | MaskedLayer
float | Via
float | Violation
float | WrongDirection

The documentation for this struct was generated from the following file:

- /home/chr/devel/PhD/Environment/pub/PCBEnv/pcbenv/cxx/NavGrid.hpp